# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2017-08-20 18:22
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('plugs_configuration', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='configuration',
            name='type',
            field=models.CharField(choices=[('INTERNAL', 'INTERNAL'), ('EXTERNAL', 'EXTERNAL'), ('USER', 'USER')], default='EXTERNAL', max_length=10),
        ),
    ]
