# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2017-01-07 18:23
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Configuration',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True)),
                ('key', models.CharField(max_length=20)),
                ('value', models.TextField()),
            ],
            options={
                'verbose_name': 'configuration',
                'verbose_name_plural': 'configurations',
            },
        ),
    ]
